<?php
/* $Id: finnish-iso-8859-1.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */

/*
 * Translated by Jouni Khknen, <address withdrawn>
 * Previous translations by Visa Kopu, <visa@visakopu.net>
 */

$charset = 'iso-8859-1';
$text_dir = 'ltr';
$number_thousands_separator = '';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('tavua', 'kt', 'Mt', 'Gt', 'Tt', 'Pt', 'Et');

$day_of_week = array('Su', 'Ma', 'Ti', 'Ke', 'To', 'Pe', 'La');
$month = array('Tammi', 'Helmi', 'Maalis', 'Huhti', 'Touko', 'Kes', 'Hein', 'Elo', 'Syys', 'Loka', 'Marras', 'Joulu');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y klo %H:%M';

$timespanfmt = '%s piv, %s tuntia, %s minuuttia ja %s sekuntia';

'The number of rows waiting to be written in INSERT DELAY queues.';
'Kertoo, kuinka monta INSERT DELAY -jonoissa olevaa rivi odotetaan kirjoitettavan.';

$strAbortedClients = 'Keskeytetty';
$strAccessDeniedCreateConfig = 'Todennkinen syy tlle on se, ettet ole luonut asetustiedostoa. Voit kytt %1$sasetusskripti%2$s asetustiedoston luomiseen.';
$strAccessDeniedExplanation = 'phpMyAdmin yritti saada yhteyden MySQL-palvelimeen, mutta se torjui yhteyden. Tarkista palvelin, kyttjnimi ja salasana config.inc.php-tiedostosta ja varmista, ett ne vastaavat MySQL-palvelimen jrjestelmnvalvojan antamia tietoja.';
$strAccessDenied = 'Psy kielletty';
$strAction = 'Toiminnot';
$strAddAutoIncrement = 'Lis \'AUTO_INCREMENT\' -arvo';
$strAddClause = 'Lis %s';
$strAddConstraints = 'Lis rajoitteet';
$strAddDeleteColumn = 'Lis/poista sarakkeita';
$strAddDeleteRow = 'Lis/poista hakuehtoja';
$strAddFields = 'Lis %s kentt()';
$strAddHeaderComment = 'Lis oma kommentti otsikkoon (\\n on rivinvaihto)';
$strAddIntoComments = 'Lis kommentteihin';
$strAddNewField = 'Lis sarake';
$strAddPrivilegesOnDb = 'Lis kyttoikeudet seuraavaan tietokantaan';
$strAddPrivilegesOnTbl = 'Lis kyttoikeudet seuraavaan tauluun';
$strAddSearchConditions = 'Lis hakuehtoja ("where"-lauseen sislt):';
$strAddToIndex = 'Lis indeksiin %s sarake(tta)';
$strAddUser = 'Lis uusi kyttj';
$strAddUserMessage = 'Olet lisnnyt uuden kyttjn.';
$strAdministration = 'Pkyttjyys';
$strAffectedRows = 'Muutettuja rivej:';
$strAfterInsertBack = 'Takaisin';
$strAfterInsertNewInsert = 'Lis uusi rivi';
$strAfterInsertNext = 'Muokkaa seuraavaa rivi';
$strAfterInsertSame = 'Palaa tlle sivulle';
$strAfter = 'Jlkeen sarakkeen: %s';
$strAll = 'Kaikki';
$strAllowInterrupt = 'Salli tuonnin keskeyttminen, mikli skripti huomaa ylittvns aikarajoituksen. Tt kannattaa kytt suurten tiedostojen tuomiseen; se voi kuitenkin aiheuttaa hiriit transaktioihin (tapahtumiin).';
$strAllTableSameWidth = 'Nyt kaikki taulut samanlevyisin?';
$strAlterOrderBy = 'Lajittele taulu';
$strAnalyzeTable = 'Analysoi taulu';
$strAnd = 'Ja';
$strAndThen = 'ja sen jlkeen';
$strAngularLinks = 'Kulmikkaat linkit';
$strAnIndex = 'Sarakkeelle %s on listty indeksi';
$strAnyHost = 'Mik tahansa palvelin';
$strAny = 'Mik tahansa';
$strAnyUser = 'Mik tahansa kyttj';
$strApproximateCount = 'Saattaa olla summittainen. Katso FAQ 3.11';
$strAPrimaryKey = 'Sarakkeelle %s on luotu ensisijainen avain';
$strArabic = 'Arabialainen';
$strArmenian = 'Armenialainen';
$strAscending = 'Nouseva';
$strAtBeginningOfTable = 'Taulun alkuun';
$strAtEndOfTable = 'Taulun loppuun';
$strAttr = 'Attribuutit';
$strAutomaticLayout = 'Automaattinen ulkoasu';

$strBack = 'Takaisin';
$strBaltic = 'Baltilainen';
$strBeginCut = 'ALOITA CUT';
$strBeginRaw = 'ALOITA RAW';
$strBinary = 'Binridata';
$strBinaryDoNotEdit = 'Binridataa - l muokkaa';
$strBinaryLog = 'Binriloki';
$strBinLogEventType = 'Tapahtumatyyppi';
$strBinLogInfo = 'Informaatio';
$strBinLogName = 'Lokin nimi';
$strBinLogOriginalPosition = 'Alkuperinen sijainti';
$strBinLogPosition = 'Sijainti';
$strBinLogServerId = 'Palvelimen ID';
$strBookmarkAllUsers = 'Anna kaikkien kyttjien kytt tt kirjanmerkki';
$strBookmarkCreated = 'Kirjanmerkki %s luotu';
$strBookmarkDeleted = 'Kirjanmerkki on poistettu.';
$strBookmarkLabel = 'Tunniste';
$strBookmarkQuery = 'Tallennettu SQL-kysely';
$strBookmarkReplace = 'Korvaa samanniminen, olemassaoleva kirjanmerkki';
$strBookmarkThis = 'Tallenna SQL-kysely';
$strBookmarkView = 'Nyt';
$strBrowseDistinctValues = 'Selaa erillisi arvoja';
$strBrowseForeignValues = 'Selaa vieraita arvoja';
$strBrowse = 'Selaa';
$strBufferPoolActivity = 'Puskurivarannon aktiivisuus';
$strBufferPool = "Puskurivaranto";
$strBufferPoolUsage = "Puskurivarannon kytt";
$strBufferReadMisses = 'Eponnistuneet lukuyritykset';
$strBufferReadMissesInPercent = 'Eponnistuneet lukuyritykset: %';
$strBufferWriteWaitsInPercent = 'Kirjoitusviipeet: %';
$strBufferWriteWaits = 'Viive ennen kirjoitusta';
$strBulgarian = 'Bulgarialainen';
$strBusyPages = "Kytss olevat sivut";
$strBzError = 'phpMyAdmin ei voinut pakata vedosta johtuen rikkinisest Bz2-laajennuksesta tss php:n versiossa. On suositeltavaa asettaa <code>$cfg[\'BZipDump\']</code>-direktiivi phpMyAdminin konfigurointitiedostosta arvoksi <code>FALSE</code>. Jos haluat kytt Bz2-pakkauksen toimintoja, sinun pit pivitt uusimpaan php:n versioon. Katso listietoja php bug reportista: %s .';
$strBzip = '"bzip-pakkaus"';

$strCalendar = 'Kalenteri';
$strCancel = 'Peruuta';
$strCanNotLoadExportPlugins = 'Vientilisosia ei voitu ladata; tarkista asennuksesi!';
$strCanNotLoadImportPlugins = 'Tuontiin tarvittavaa lisosaa ei voida tuoda, tarkista asennuksen asetukset!';
$strCannotLogin = 'MySQL-palvelimelle ei voitu kirjautua sisn';
$strCantLoad = 'en voi ladata laajennusta %s,<br />ole hyv, ja tarkista PHP:n asetukset';
$strCantLoadRecodeIconv = 'Merkistn konvertointiin tarvittavaa iconv- tai recode-laajennusta ei voitu ladata. Muokkaa PHP:n asetuksia ja salli niden laajennusten kytt tai muuta phpMyAdminin asetuksia niin ettei konvertointia suoriteta.';
$strCantRenameIdxToPrimary = 'Indeksi ei voi muuttaa PRIMARY-nimiseksi!';
$strCantUseRecodeIconv = 'iconv-, libiconv- tai recode_string-funktioita ei voitu kytt. Tarkista PHP:n asetukset.';
$strCardinality = 'Kardinaliteetti';
$strCaseInsensitive = 'kirjainkoolla ei vli';
$strCaseSensitive = 'tarkka kirjainkoko';
$strCentralEuropean = 'Keskieurooppalainen';
$strChangeCopyModeCopy = '... silyt vanha kyttj.';
$strChangeCopyModeDeleteAndReload = ' ... poista vanha kyttj kyttjtauluista ja lataa kyttoikeudet sen jlkeen uudelleen.';
$strChangeCopyModeJustDelete = ' ... poista vanha kyttj kyttjtauluista.';
$strChangeCopyMode = 'Luo uusi kyttj samoilla kyttoikeuksilla ja ...';
$strChangeCopyModeRevoke = ' ...peruuta kaikki aktiiviset kyttoikeudet vanhalta kyttjlt ja tuhoa se sen jlkeen.';
$strChangeCopyUser = 'Vaihda sisnkirjautumistietoja / Kopioi kyttj';
$strChangeDisplay = 'Valitse nytettv sarake';
$strChange = 'Muokkaa';
$strChangePassword = 'Vaihda salasanaa';
$strCharset = 'Merkistkoodaus';
$strCharsetOfFile = 'Tiedoston merkist:';
$strCharsetsAndCollations = 'Merkistkoodaukset ja aakkosjrjestykset';
$strCharsets = 'Merkistt';
$strCheckAll = 'Valitse kaikki';
$strCheckOverhead = 'Valitse kyttmttmt taulut'; //?
$strCheckPrivs = 'Hallitse kyttoikeuksia';
$strCheckPrivsLong = 'Hallitse tietokannan &quot;%s&quot; kyttoikeuksia.';
$strCheckTable = 'Tarkista taulu';
$strChoosePage = 'Valitse muokattava sivu';
$strColComFeat = 'Sarakkeiden kommentit nkyviss';
$strCollation = 'Aakkosjrjestys';
$strColumnNames = 'Sarakkeiden nimet';
$strColumnPrivileges = 'Sarakekohtaiset kyttoikeudet';
$strCommand = 'Komento';
$strCommentsForTable = 'KOMMENTIT TAULULLE';
$strComments = 'Kommentit';
$strCompatibleHashing = 'MySQL&nbsp;4.0 -yhteensopiva';
$strCompleteInserts = 'Kokonaiset insert-lauseet';
$strCompression = 'Pakkaus';
$strCompressionWillBeDetected = 'Seuraavat tiedostopakkausmuodot havaitaan automaattisesti: %s';
$strConfigDefaultFileError = 'En voi ladata oletusasetuksia kohteesta: "%1$s"';
$strConfigFileError = 'phpMyAdmin ei pysty lukemaan asetustiedostoa.<br />Tm saattaa johtua virheest, jonka PHP lysi tiedostosta tai tiedoston puuttumisesta.<br />Voit avata tiedoston allaolevasta linkist ja lukea mahdolliset PHP-virheilmoituikset. Todennkisimmin joltain rivilt puuttuu lainausmerkki tai puolipiste.<br />Jos linkist avautuva sivu on tyhj, asetustiedostosta ei lytynyt virhett.';
$strConfigureTableCoord = 'Mrittele koordinaatit taululle %s';
$strConnectionError = 'En voi yhdist: virheelliset asetukset.';
$strConnections = 'Yhteydenotot';
$strConstraintsForDumped = 'Rajoitteet vedostauluille';
$strConstraintsForTable = 'Rajoitteet taululle';
$strCookiesRequired = 'Selaimessa on oltava evsteet kytss tst eteenpin.';
$strCopyDatabaseOK = 'Tietokanta %s on kopioitu tietokannaksi %s';
$strCopy = 'Kopioi';
$strCopyTable = 'Kopioi taulu toiseen tauluun nimell (tietokanta<b>.</b>taulu):';
$strCopyTableOK = 'Taulu %s on kopioitu nimelle %s.';
$strCopyTableSameNames = 'Taulua ei voida kopioida itseens!';
$strCouldNotKill = 'phpMyAdmin ei voinut lopettaa siett %s. Se on todennkisesti jo suljettu.';
$strCreateDatabaseBeforeCopying = 'Suorita CREATE DATABASE ennen kopioimista';
$strCreateIndex = 'Luo &nbsp;%s:n sarakkeen indeksi';
$strCreateIndexTopic = 'Luo uusi indeksi';
$strCreate = 'Luo';
$strCreateNewDatabase = 'Luo uusi tietokanta';
$strCreateNewTable = 'Luo uusi taulu tietokantaan %s';
$strCreatePage = 'Luo uusi sivu';
$strCreatePdfFeat = 'PDF-tiedostojen luonti';
$strCreateRelation = 'Luo relaatio';
$strCreateTable  = 'Luo taulu';
$strCreateUserDatabaseName = 'Luo samanniminen tietokanta ja anna kaikki oikeudet';
$strCreateUserDatabaseNone = 'Ei mitn';
$strCreateUserDatabase = 'Tietokanta kyttjlle';
$strCreateUserDatabaseWildcard = 'Anna kaikki oikeudet tietokannalle jokerimerkki kytten (username\_%)';
$strCreationDates = 'Luonti/pivitys/tarkistus -pivykset';
$strCriteria = 'Hakuehdot';
$strCroatian = 'Kroaatti';
$strCSV = 'CSV';
$strCyrillic = 'Kyrillinen';
$strCzechSlovak = 'Tsekkoslovakialainen';
$strCzech = 'Tshekkilinen';

$strDanish = 'Tanskalainen';
$strDatabaseEmpty = 'Tietokannan nimi on tyhj!';
$strDatabaseExportOptions = 'Tietokannan tulostusvalinnat';
$strDatabaseHasBeenDropped = 'Tietokanta %s on pudotettu.';
$strDatabasesDropped = '%s tietokantaa pudotettiin onnistuneesti.';
$strDatabasesStatsDisable = 'Poista tilastot kytst';
$strDatabasesStatsEnable = 'Ota tilastot kyttn';
$strDatabasesStatsHeavyTraffic = 'Huom: Tietokantatilastojen kyttnotto tlt ksin saattaa aiheuttaa runsaasti liikennett Internet-palvelimen ja MySQL-palvelimen vlille.';
$strDatabasesStats = 'Tietokantatilastot';
$strDatabases = 'Tietokannat';
$strDatabase = 'Tietokanta';
$strData = 'Data';
$strDataDict = 'Datasanakirja';
$strDataOnly = 'Vain data';
$strDataPages = "Dataa sisltvt sivut";
$strDBComment = 'Tietokannan kommentti: ';
$strDBCopy = 'Luo tietokannasta toinen tietokanta nimell';
$strDbIsEmpty = 'Tietokanta on tyhj!';
$strDbPrivileges = 'Tietokantakohtaiset kyttoikeudet';
$strDBRename = 'Muuta tietokannan nimi';
$strDbSpecific = 'tietokantakohtainen';
$strDefaultEngine = "%s on tmn MySQL-palvelimen oletusarvoinen tallennustilamoottori.";
$strDefault = 'Oletusarvo';
$strDefaultValueHelp = 'Syt oletusarvoihin vain yksininen arvo (kyttmtt kenoviivamerkintj tai lainausmerkkej) tss muodossa: a';
$strDefragment = 'Eheyt taulu';
$strDelayedInserts = 'Kyt viivstettyj insert-lauseita';
$strDeleteAndFlushDescr = 'Tm on siivoin tapa, mutta kyttoikeuksien lataaminen uudelleen saattaa kest jonkin aikaa.';
$strDeleteAndFlush = 'Poista kyttjt ja lataa kyttoikeudet sen jlkeen uudelleen.';
$strDeleted = 'Rivi on poistettu';
$strDeletedRows = 'Poistetut rivit:';
$strDeleteNoUsersSelected = 'Yhtn kyttj ei valittu poistettavaksi!';
$strDelete = 'Poista';
$strDeleteRelation = 'Poista relaatio';
$strDeleting = 'Poistetaan: %s';
$strDelimiter = 'Rajamerkki';
$strDelOld = 'Nykyisell sivulla on viittauksia tauluihin, joita ei en ole olemassa. Haluatko poistaa nuo viittaukset?';
$strDescending = 'Laskeva';
$strDescription = 'Kuvaus';
$strDesignerHelpDisplayField = 'Ilmaisinkentt nkyy vaaleanpunaisena. Asettaaksesi kentn ilmaisinkentksi paina "Valitse nytettv kentt" -kuvaketta ja paina sitten sopivaa kenttnime.';
$strDesigner = 'Suunnittelija';
$strDictionary = 'sanakirja';
$strDirectLinks = 'Suorat linkit';
$strDirtyPages = "Epsiistit sivut";
$strDisabled = 'Pois plt';
$strDisableForeignChecks = 'l kyt vieraiden avainten tarkistusta';
$strDisplayFeat = 'Ulkoasun asetukset';
$strDisplayOrder = 'Lajittelujrjestys:';
$strDisplayPDF = 'Nyt PDF-kaavio';
$strDoAQuery = 'Suorita "esimerkin mukainen kysely" (jokerimerkki: "%")';
$strDocSQL = 'DocSQL';
$strDocu = 'Ohjeet';
$strDoYouReally = 'Oletko varma ett haluat ';
$strDropDatabaseStrongWarning = 'Olet aikeissasi HVITT kokonaisen tietokannan!';
$strDrop = 'Pudota';
$strDropUsersDb = 'Pudota (poista) tietokannat, joilla on sama nimi kuin kyttjill.';
$strDumpingData = 'Vedostetaan tietoa taulusta';
$strDumpSaved = 'Vedos tallennettiin tiedostoon %s.';
$strDumpXRows = 'Tee vedos %s rivist, alkaen rivist: %s.';
$strDynamic = 'dynaaminen';

$strEdit = 'Muokkaa';
$strEditPDFPages = 'Muokkaa PDF-sivuja';
$strEditPrivileges = 'Muokkaa kyttoikeuksia';
$strEffective = 'Varsinainen';
$strEmptyResultSet = 'MySQL palautti tyhjn vastauksen (ts. nolla rivi).';
$strEmpty = 'Tyhjenn';
$strEnabled = 'Pll';
$strEncloseInTransaction = 'Lis transaktio (tapahtuma)';
$strEndCut = 'LOPETA CUT';
$strEnd = 'Loppu';
$strEndRaw = 'LOPETA RAW';
$strEngineAvailable = "%s on kytettviss tll MySQL-palvelimella.";
$strEngineDisabled = "%s on otettu pois kytst tlt MySQL-palvelimelta.";
$strEngines = "Moottorit";
$strEngineUnsupported = "Tm MySQL-palvelin ei tue %s-tallennustilamoottoria.";
$strEnglish = 'Englantilainen';
$strEnglishPrivileges = ' Huom! MySQL-kyttoikeuksien nimet ovat englanniksi! ';
$strErrorInZipFile = 'Virhe ZIP-paketissa:';
$strErrorRelationAdded = 'Virhe: Relaatiota ei luotu.';
$strErrorRelationExists = 'Virhe: relaatio on jo olemassa.';
$strErrorRenamingTable = 'Virhe annettaessa taululle %1$s nime %2$s';
$strErrorSaveTable = 'Virhe tallennettaessa koordinaatteja Suunnitelijaan.';
$strError = 'Virhe';
$strEscapeWildcards = 'Jokerimerkkien _ ja % eteen on listtv \-merkki, jotta ne nkyisivt oikein';
$strEsperanto = 'Esperanto';
$strEstonian = 'Virolainen';
$strExcelEdition = 'Excel-muokkaus';
$strExecuteBookmarked = 'Suorita kirjanmerkkeihin listty kysynt';
$strExplain = 'Selit SQL-kysely';
$strExportImportToScale = 'Vie/tuo skaalaan';
$strExportMustBeFile = 'Valittu vientityyppi on tallennettava tiedostoon!';
$strExport = 'Vienti';
$strExtendedInserts = 'Laajennetut insert-lauseet';
$strExtra = 'Listiedot';

$strFailedAttempts = 'Eponnistuneet yritykset';
$strFieldHasBeenDropped = 'Sarake %s on pudotettu';
$strFieldInsertFromFileTempDirNotExists = 'Virhe lhetetty tiedostoa siirrettess, katso FAQ 1.11';
$strField = 'Sarake';
$strFieldsEnclosedBy = 'Sarakkeiden ymprintimerkki';
$strFieldsEscapedBy = 'Koodinvaihtomerkki (escape)';
$strFields = 'Sarakkeet';
$strFieldsTerminatedBy = 'Sarakkeiden erotinmerkki';
$strFileAlreadyExists = 'Tiedosto %s on jo olemassa palvelimella, vaihda tiedostonime tai tarkista korvaus-asetuksen tila.';
$strFileCouldNotBeRead = 'Tiedostoa ei voida lukea';
$strFileNameTemplateDescriptionDatabase = 'tietokannan nimi';
$strFileNameTemplateDescriptionServer = 'palvelimen nimi';
$strFileNameTemplateDescriptionTable = 'taulun nimi';
$strFileNameTemplateDescription = 'Tm arvo on %1$sstrftime%2$s-funktion mukainen, joten voit kytt ajanmuodostostusmerkkijonoja. Lisksi tapahtuu seuraavat muutokset: %3$s. Muu teksti pysyy alkuperisen.';
$strFileNameTemplateRemember = 'muista pohja';
$strFileNameTemplate = 'Tiedostonimen pohja';
$strFileToImport = 'Tuotava tiedosto';
$strFixed = 'kiinte';
$strFlushPrivilegesNote = 'Huom: phpMyAdmin hakee kyttjien kyttoikeudet suoraan MySQL-palvelimen kyttoikeustauluista. Niden taulujen sislt saattaa erota palvelimen kyttmist kyttoikeuksista, jos niihin on tehty muutoksia manuaalisesti. Tllin sinun on %sladattava kyttoikeudet uudestaan%s ennen kuin jatkat.';
$strFlushQueryCache = 'Tyhjenn kyselymuisti';
$strFlushTables = 'Tyhjenn (sulje) kaikki taulut';
$strFlushTable = 'Tyhjenn taulun vlimuisti ("FLUSH")';
$strFontSize = 'Fonttikoko';
$strForeignKeyError = 'Virhe luotaessa vierasta avainta (tarkista tietotyypit)';
$strFormat = 'Muoto';
$strFormEmpty = 'Tarvittava tieto puuttuu lomakkeesta!';
$strFreePages = "Vapaat sivut";
$strFullText = 'Koko tekstit';
$strFunction = 'Funktio';
$strFunctions = 'Funktiot';

$strGenBy = 'Luontiymprist';
$strGeneralRelationFeat = 'Yleiset relaatio-ominaisuudet';
$strGenerate = 'Keksi';
$strGeneratePassword = 'Keksi salasana';
$strGenTime = 'Luontiaika';
$strGeorgian = 'Georgialainen';
$strGerman = 'Saksalainen';
$strGlobal = 'globaali';
$strGlobalPrivileges = 'Globaalit kyttoikeudet';
$strGlobalValue = 'Globaali arvo';
$strGo = 'Siirry';
$strGrantOption = 'Saantioikeudet';
$strGreek = 'Kreikkalainen';
$strGzip = '"gzip-pakkaus"';

$strHandler = 'Ksittelij';
$strHasBeenAltered = 'on muutettu.';
$strHasBeenCreated = 'on luotu.';
$strHaveToShow = 'Valitse vhintn yksi sarake';
$strHebrew = 'Hebrealainen';
$strHelp = 'Ohje';
$strHide         = 'Ktke';
$strHideShowAll = 'Ktke/nyt kaikki';
$strHideShowNoRelation = 'Ktke/nyt taulut, joilla ei ole relaatiota';
$strHome = 'Etusivu';
$strHomepageOfficial = 'phpMyAdminin kotisivut';
$strHostEmpty = 'Palvelimen nimi puuttuu!';
$strHost = 'Palvelin';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHungarian = 'Unkarilainen';

$strIcelandic = 'Islantilainen';
$strId = 'ID';
$strIdxFulltext = 'Koko teksti';
$strIEUnsupported = 'Internet Explorer ei tue tt toimintoa.';
$strIgnoreDuplicates = 'l vlit kaksinkertaisista riveist';
$strIgnoreInserts = 'Kyt IGNORE:a INSERT-komennoissa';
$strIgnore = 'Jt huomiotta';
$strImportExportCoords = 'Tuo/vie PDF-skeeman koordinaatit';
$strImportFiles = 'Tuo tiedostoja';
$strImportFormat = 'Tuotavan tiedoston muoto';
$strImportSuccessfullyFinished = 'Tuonti onnistui, %d kysely suoritettu.';
$strImport = 'Tuonti';
$strIndexes = 'Indeksit';
$strIndexHasBeenDropped = 'Indeksi %s on pudotettu';
$strIndex = 'Indeksi';
$strIndexName = 'Indeksin nimi:';
$strIndexType = 'Indeksin tyyppi:';
$strIndexWarningTable = 'Taulun `%s` indeksien kanssa on ongelmia';
$strInnoDBAutoextendIncrement = "Automaattisen laajentamisen koko";
$strInnoDBAutoextendIncrementDesc = "Laajentamiskoko automaattisesti suurenevan taulutilan koon laajentamiseksi sen tyttyess.";
$strInnoDBBufferPoolSizeDesc = 'Kertoo koon siit muistipuskurista, jota InnoDB kytt taulujen tietojen ja indeksien siirtmiseen vlimuistiin.';
$strInnoDBBufferPoolSize = 'Puskurivarannon koko';
$strInnoDBDataFilePath = "Datatiedostot";
$strInnoDBDataHomeDir = "Datan kotihakemisto";
$strInnoDBDataHomeDirDesc = "Hakemistopolun yhteinen osa kaikille InnoDB-datatiedostoille.";
$strInnoDBPages = 'sivua';
$strInnoDBRelationAdded = 'InnoDB-relaatio luotu';
$strInnodbStat = 'InnoDB:n tila';
$strInsecureMySQL = 'Asetustiedostosi kytt asetuksia, jotka viittaavat MySQL-palvelimen oletusarvoiseen kyttjn (root ilman salasanaa). Tllaisin asetuksin MySQL-palvelin on altis hykkyksille. Tm tietoturvariski olisi syyt korjata pikimmiten!';
$strInsertAsNewRow = 'Lis uutena rivin';
$strInsertedRowId = 'Sijoitetun rivin id:';
$strInsertedRows = 'Listyt rivit:';
$strInsert = 'Lis rivi';
$strInternalNotNecessary = '* Sisist relaatiota ei tarvita silloin, kun sellainen on jo InnoDB:ss.';
$strInternalRelationAdded = 'Sisinen relaatio luotu';
$strInternalRelations = 'Sisiset relaatiot';
$strInUse = 'kytss';
$strInvalidAuthMethod = 'Asetuksissa on virheellinen todennustapa:';
$strInvalidColumnCount = 'Sarakkeiden mrn on oltava enemmn suurempi kuin nolla.';
$strInvalidColumn = 'Virheellinen sarake (%s) mritelty!';
$strInvalidCSVFieldCount = 'Virheellinen kenttien mr CSV-sytteess rivill %d.';
$strInvalidCSVFormat = 'Virheellinen muoto CSV-sytteess rivill %d.';
$strInvalidCSVParameter = 'Virheellinen parametri CSV-tuonnille: %s';
$strInvalidDatabase = 'Virheellinen tietokanta';
$strInvalidFieldAddCount = 'Sinun on listtv vhintn yksi kentt.';
$strInvalidFieldCount = 'Taulussa tytyy olla vhintn yksi kentt.';
$strInvalidLDIImport = 'Tm lisosa ei tue pakattujen tuontien kytt!';
$strInvalidRowNumber = '%d on virheellinen rivinumero.';
$strInvalidServerHostname = 'Palvelimella %1$s virheellinen nimi. Tarkista asetukset.';
$strInvalidServerIndex = 'Virheellinen palvelinindeksi: "%s"';
$strInvalidTableName = 'Virheellinen taulun nimi';

$strJapanese = 'Japanilainen';
$strJoins = 'Liitokset';
$strJumpToDB = 'Hypp tietokantaan &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Poistetut&quot; kyttjt voivat edelleen kytt tavalliseen tapaan palvelinta, ellei kyttoikeuksia ladata uudestaan.';
$strJustDelete = 'Poista kyttjt vain kyttoikeustauluista.';

$strKeepPass = 'l vaihda salasanaa';
$strKeyCache = 'Avainvlimuisti';
$strKeyname = 'Avaimen nimi';
$strKill = 'Lopeta';
$strKnownExternalBug = 'Toimintoon %s vaikuttaa tunnettu vika, katso %s';
$strKorean = 'Korealainen';

$strLandscape = 'Landscape';
$strLanguage = 'Kieli';
$strLanguageUnknown = 'Tuntematon kieli: %1$s.';
$strLatchedPages = "Lukitut sivut";
$strLatexCaption = 'Taulun otsikko';
$strLatexContent = 'Taulun __TABLE__ sislt';
$strLatexContinuedCaption = 'Jatkettu taulun otsikko';
$strLatexContinued = '(jatkuu)';
$strLatexIncludeCaption = 'Sisllyt taulun otsikko';
$strLatexLabel = 'Tunniste';
$strLaTeX = 'LaTeX';
$strLatexStructure = 'Taulun __TABLE__ rakenne';
$strLatvian = 'Latvialainen';
$strLDI = 'CSV kytten LOAD DATA -kysely';
$strLDILocal = 'Kyt LOCAL-avainsanaa';
$strLengthSet = 'Pituus/Arvot*';
$strLimitNumRows = 'Rivej sivua kohti';
$strLinesTerminatedBy = 'Rivien erotinmerkki';
$strLinkNotFound = 'Linkki ei lydy';
$strLinksTo = 'Linkitys sarakkeeseen:';
$strLithuanian = 'Liettualainen';
$strLocalhost = 'Paikallinen';
$strLocationTextfile = 'Tiedoston sijainti';
$strLoginInformation = 'Sisnkirjautumistiedot';
$strLogin = 'Kirjaudu sisn';
$strLogout = 'Poistu';
$strLogPassword = 'Salasana:';
$strLogServer = 'Palvelin';
$strLogUsername = 'Kyttjtunnus:';
$strLongOperation = "Tm toimenpide saattaa kest pitkn. Jatketaanko silti?";

$strMaxConnects = 'enim. yhtaikaisia yhteyksi';
$strMaximalQueryLength = 'Luodun kyselyn enimmispituus';
$strMaximumSize = 'Enimmiskoko: %s%s';
$strMbExtensionMissing = 'PHP-laajennusta mbstring ei lytynyt ja vaikuttaa silt, ett kytt multibyte-merkistkoodausta. Ilman mbstring-laajennusta phpMyAdmin ei osaa jaotella merkkijonoja oikein, ja tm saattaa johtaa odottamattomiin tuloksiin.';
$strMbOverloadWarning = 'PHP:n asetuksissa on "mbstring.func_overload" -valinta pll. Tm valinta ei sovi yhteen phpMyAdminin kanssa ja saattaa hvitt tietoja!';
$strMIME_available_mime = 'Mahdolliset MIME-tyypit';
$strMIME_available_transform = 'Mahdolliset muunnokset';
$strMIME_description = 'Kuvaus';
$strMIME_MIMEtype = 'MIME-tyyppi';
$strMIME_nodescription = 'Tlle muunnokselle ei ole saatavilla kuvausta.<br />Kysy tekijlt, mit %s tekee.';
$strMIME_transformation_note = 'Nhdksesi luettelon saatavilla olevista muunnosvaihtoehdoista ja niiden MIME-tyyppien muunnoksista, paina %smuunnoksen kuvaukset%s-kohtaa';
$strMIME_transformation_options = 'Muunnosvaihtoehdot';
$strMIME_transformation_options_note = 'Syt muunnosvalinnoille arvot kytten tt formaattia: \'a\', 100, b,\'c\'...<br />Jos tarvitset arvoissa kenoviivaa ("\") tai yksittist lainausmerkki ("\'"), lis merkin eteen kenoviiva (esim. \'\\\\xyz\' tai \'a\\\'b\').';
$strMIME_transformation = 'Selaimen muunnos (transformation)';
$strMIMETypesForTable = 'MIME-TYYPIT TAULULLE';
$strMIME_without = 'MIME-tyypeill, jotka on kursivoitu, ei ole erillist muunnostoimintoa';
$strModifications = 'Muutokset tallennettu';
$strModifyIndexTopic = 'Muokkaa indeksi';
$strModify = 'Muokkaa';
$strMoveMenu = 'Siirr valikko';
$strMoveTableOK = 'Taulu %s on siirretty %s.';
$strMoveTableSameNames = 'Taulua ei voi siirt itseens!';
$strMoveTable = 'Siirr taulu toiseen tauluun (tietokanta<b>.</b>taulu):';
$strMultilingual = 'monikielinen';
$strMyISAMDataPointerSize = "Dataosoittimen koko";
$strMyISAMDataPointerSizeDesc = "Osoittimen oletuskoko tavuina, kytettvksi CREATE TABLE -kyselyn yhteydess MyISAM-tauluissa, silloin kun MAX_ROWS-valintaa ei ole mritelty.";
$strMyISAMMaxExtraSortFileSizeDesc = "Jos MyISAM-indeksin nopeaan luomiseen kytetty vliaikaistiedosto on suurempi kuin avainvlimuistin kytt tll mritellyn mrn mukaisesti, suositellaan vlimuistitoiminnon kytt.";
$strMyISAMMaxExtraSortFileSize = "Enimmiskoko vliaikaistiedostoille indeksin luonnissa";
$strMyISAMMaxSortFileSizeDesc = "MySQL-palvelimen kyttn tarkoitettu vliaikaistiedoston suurin koko MyISAM-indeksien uudelleenlatausta varten (REPAIR TABLE, ALTER TABLE tai LOAD ADTA INFILE -toimintojen aikana).";
$strMyISAMMaxSortFileSize = "Enimmiskoko vliaikaisille lajittelutiedostoille";
$strMyISAMRecoverOptions = "Automaattinen palautuminen";
$strMyISAMRecoverOptionsDesc = "Kaatuneiden MyISAM-taulujen automaattisen palauttamisen tila sellaisena kuin se on asetettu \"--myisam-recover\" -nimisen palvelimenkynnistysasetuksen kautta.";
$strMyISAMRepairThreadsDesc = "Jos tm arvo on suurempi kuin 1, lajitteluprosessi luo MyISAM-tauluindeksit rinnakkain (jokainen indeksi omalle sikeelleen), kun kytetn Korjaa-toimintoa.";
$strMyISAMRepairThreads = "Korjaa sikeet";
$strMyISAMSortBufferSizeDesc = "Puskuri joka varataan kyttn lajiteltaessa MyISAM-indeksej REPAIR TABLE -kyselyn aikana tai luotaessa indeksej CREATE INDEX - tai ALTER TABLE -kyselyll.";
$strMyISAMSortBufferSize = "Lajittelupuskurin koko";
$strMySQLCharset = 'MySQL-palvelimen merkist';
$strMysqlClientVersion = 'MySQL-asiakasversio';
$strMySQLConnectionCollation = 'MySQL-yhteyden aakkosjrjestys';
$strMySQLSaid = 'MySQL ilmoittaa: ';
$strMySQLShowProcess = 'Nyt prosessit';
$strMySQLShowStatus = 'Nyt MySQL-palvelimen ajonaikaiset tiedot';
$strMySQLShowVars = 'Nyt MySQL-palvelimen jrjestelmmuuttujat';

$strName = 'Nimi';
$strNext = 'Seuraava';
$strNoActivity = 'Yhteys on ollut toimettomana %s sekuntia tai enemmn. Kirjaudu sisn uudestaan.';
$strNoDatabases = 'Ei tietokantoja';
$strNoDatabasesSelected = 'Et valinnut yhtn tietokantaa.';
$strNoDataReceived = 'Mitn tietoa ei ole saatu tuotavaksi. Joko mitn tiedostonime ei annettu tai tiedoston koko ylitti PHP:n asetusten salliman enimmiskoon. Katso FAQ 1.16.';
$strNoDescription = 'ei kuvausta';
$strNoDetailsForEngine = "Tmn tallennustilamoottorin tilasta ei ole saatavilla tarkkoja tietoja.";
$strNoDropDatabases = '"DROP DATABASE" -kyselyjen kytt on estetty.';
$strNo = 'Ei';
$strNoExplain = 'l selit SQL-kysely';
$strNoFilesFoundInZip = 'ZIP-paketista ei lytynyt yhtn tiedostoa!';
$strNoFrames = 'phpMyAdmin toimii parhaiten <b>kehyksi</b> tukevalla selaimella.';
$strNoIndex = 'Indeksi ei ole mritelty!';
$strNoIndexPartsDefined = 'Indeksin osia ei ole mritelty!';
$strNoModification = 'Ei muutoksia';
$strNone = 'Ei mitn';
$strNoOptions = 'Tlle tiedostomuodolle ei ole valinta-asetuksia';
$strNoPassword = 'Ei mitn salasanaa';
$strNoPermission = 'Internet-palvelimella ei ole lupaa tallentaa tiedostoa %s.';
$strNoPhp = 'Ktke PHP-koodi';
$strNoPrivileges = 'Ei kyttoikeuksia';
$strNoRights = 'Sinulla ei ole tarpeeksi oikeuksia!';
$strNoRowsSelected = 'Ei yhtn rivi valittu';
$strNoSpace = 'Liian vhn tilaa tiedoston %s tallentamiseen.';
$strNoTablesFound = 'Tietokannassa ei ole tauluja.';
$strNoThemeSupport = 'Ei tukea teemojen kyttn. Tarkista asetukset ja/tai teemasi hakemistosta %s.';
$strNotNumber = 'Tm ei ole numero!';
$strNotOK = 'Ei kunnossa';
$strNotSet = '<b>%s</b>-taulua ei lytynyt tai sit ei ole mritelty %s-tiedostossa';
$strNoUsersFound = 'Kyttji ei lytynyt.';
$strNoValidateSQL = 'l tarkista SQL-kysely';
$strNull = 'Tyhj';
$strNumberOfFields = 'Kenttien mr';
$strNumberOfTables = 'Taulujen mr';
$strNumSearchResultsInTable = '%s hakutulosta taulussa <i>%s</i>';
$strNumSearchResultsTotal = '<b>Yhteens:</b> <i>%s</i> hakutulosta';
$strNumTables = 'Taulut';

$strOK = 'Kunnossa';
$strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';
$strOpenDocumentText = 'Open Document Text';
$strOpenNewWindow = 'Avaa uusi phpMyAdmin-ikkuna';
$strOperations = 'Toiminnot';
$strOperator = 'Operaattori';
$strOptimizeTable = 'Optimoi taulu';
$strOptions = 'Valinnat';
$strOr = 'Tai';
$strOverhead = 'Ylijm';
$strOverwriteExisting = 'Korvaa jo olemassaoleva(t) tiedosto(t)';

$strPageNumber = 'Sivunumero:';
$strPagesToBeFlushed = "Siistimist vaativat sivut";
$strPaperSize = 'Paperin koko';
$strPartialImport = 'Osittainen tuonti';
$strPartialText = 'Lyhennetyt tekstit';
$strPasswordChanged = 'Salasanan vaihto kyttjlle %s onnistui.';
$strPasswordEmpty = 'Salasana puuttuu!';
$strPasswordHashing = 'Salasanan salaus';
$strPasswordNotSame = 'Salasanat eivt ole samat!';
$strPassword = 'Salasana';
$strPdfDbSchema = 'Kaavio tietokannasta "%s" - Sivu %s';
$strPdfInvalidTblName = 'Taulua "%s" ei lydy!';
$strPdfNoTables = 'Ei tauluja';
$strPDF = 'PDF';
$strPDFReportExplanation = '(Luo raportin, joka sislt yksittisen taulun tiedot)';
$strPDFReportTitle = 'Raportin otsikko';
$strPerHour = 'tunnissa';
$strPerMinute = 'minuutissa';
$strPerSecond = 'sekunnissa';
$strPersian = 'Persialainen';
$strPhoneBook = 'puhelinluettelo';
$strPHP40203 = 'Kytsssi on PHP 4.2.3, joka sislt vakavan vian monitavuisissa merkkijonoissa (mbstring). Katso PHP:n virheraportti 19404. Tt PHP:n versiota ei suositella kytettvksi phpMyAdminin kanssa.';
$strPhp = 'Nyt PHP-koodi';
$strPHPVersion = 'PHP:n versio';
$strPleaseSelectPrimaryOrUniqueKey = 'Valitse ensisijainen avain tai uniikki avain';
$strPmaDocumentation = 'phpMyAdminin dokumentaatio';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> tytyy mritell asetustiedostossa!';
$strPmaWiki = 'phpMyAdminin wikisivusto';
$strPolish = 'Puolalainen';
$strPortrait = 'Pystytasossa';
$strPos1 = 'Alkuun';
$strPrevious = 'Edellinen';
$strPrimary = 'Ensisijainen';
$strPrimaryKeyHasBeenDropped = 'Ensisijainen avain on pudotettu';
$strPrimaryKeyName = 'Ensisijaisen avaimen nimen pit olla PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" saa olla <b>vain ja ainoastaan</b> ensisijaisen avaimen nimen!)';
$strPrint = 'Tulosta';
$strPrintViewFull = 'Tulostusversio (kokonaisin tekstein)';
$strPrintView = 'Tulostusversio';
$strPrivDescAllPrivileges = 'Sislt kaikki kyttoikeudet GRANT-oikeutta lukuun ottamatta.';
$strPrivDescAlterRoutine = 'Sallii talletettujen rutiinien muuntamisen ja poistamisen.';
$strPrivDescAlter = 'Sallii muuttaa olemassaolevien taulujen rakennetta.';
$strPrivDescCreateDb = 'Sallii uusien tietokantojen ja taulujen luomisen.';
$strPrivDescCreateRoutine = 'Sallii talletettujen rutiinien luomisen.';
$strPrivDescCreateTbl = 'Sallii uusien taulujen luomisen.';
$strPrivDescCreateTmpTable = 'Sallii vliaikaistaulujen luomisen.';
$strPrivDescCreateUser = 'Sallii kyttjtilien luomisen, poistamisen ja uudelleennimemisen.';
$strPrivDescCreateView = 'Sallii uusien nkymien luomisen.';
$strPrivDescDelete = 'Sallii tietojen poistamisen.';
$strPrivDescDropDb = 'Sallii tietokantojen ja taulujen pudottamisen.';
$strPrivDescDropTbl = 'Sallii taulujen pudottamisen.';
$strPrivDescExecute5 = 'Sallii talletettujen rutiinien suorittamisen.';
$strPrivDescExecute = 'Sallii talletettujen proseduurien suorittamisen; Ei vaikutusta tss MySQL-palvelimen versiossa.';
$strPrivDescFile = 'Sallii tietojen tuomisen tiedostosta ja viemisen tiedostoon.';
$strPrivDescGrant = 'Sallii kyttjien ja kyttoikeuksien lismisen lataamatta kyttoikeustauluja uudestaan.';
$strPrivDescIndex = 'Sallii indeksien luomisen ja pudottamisen.';
$strPrivDescInsert = 'Sallii tietojen lismisen ja korvaamisen.';
$strPrivDescLockTables = 'Sallii taulujen lukitsemisen nykyiselle sikeelle.';
$strPrivDescMaxConnections = 'Rajoittaa kyttjn tunnissa luomien uusien yhteyksien enimmismrn tunnissa.';
$strPrivDescMaxQuestions = 'Rajoittaa kyttjn tunnissa palvelimelle lhettmien kyselyjen mrn.';
$strPrivDescMaxUpdates = 'Rajoittaa, kuinka monta monta kertaa kyttj saa suorittaa tauluihin tai tietokantoihin muutoksia tekevi komentoja tunnin aikana.';
$strPrivDescMaxUserConnections = 'Asettaa rajan kyttjn yhtaikaisten yhteyksien mrlle.';
$strPrivDescProcess3 = 'Sallii muiden kyttjien prosessien lopettamisen.';
$strPrivDescProcess4 = 'Sallii kokonaisten kyselyjen nyttmisen prosessilistassa.';
$strPrivDescReferences = 'Ei vaikutusta tss MySQL-palvelimen versiossa.';
$strPrivDescReload = 'Sallii palvelinasetusten uudelleenlataamisen ja palvelimen vlimuistin tyhjentmisen.';
$strPrivDescReplClient = 'Antaa kyttjlle oikeuden kysy, miss ali-/ppalvelimet sijaitsevat.';
$strPrivDescReplSlave = 'Tarvitaan replikaatio-alipalvelimia varten.';
$strPrivDescSelect = 'Sallii tietojen lukemisen.';
$strPrivDescShowDb = 'Sallii koko tietokantalistan kytn.';
$strPrivDescShowView = 'Sallii SHOW CREATE VIEW -kyselyjen suorittamisen.';
$strPrivDescShutdown = 'Sallii palvelimen sammuttamisen.';
$strPrivDescSuper = 'Sallii yhdistmisen silloinkin kun yhteyksien enimmismr on saavutettu; Tarvitaan useissa pkyttjn toiminnoissa, kuten globaalien muuttujien asettamisessa ja muiden kyttjien sikeiden lopettamisessa.';
$strPrivDescUpdate = 'Sallii tietojen muuttamisen.';
$strPrivDescUsage = 'Ei kyttoikeuksia.';
$strPrivileges = 'Kyttoikeudet';
$strPrivilegesReloaded = 'Kyttoikeuksien uudelleenlataus onnistui.';
$strProcedures = 'Proseduurit';
$strProcesses = 'Prosessit';
$strProcesslist = 'Prosessilista';
$strProtocolVersion = 'Protokollan versio';
$strPutColNames = 'Laita sarakkeiden nimet ensimmiselle riville';

$strQBEDel = 'Poista';
$strQBE = 'Haku';
$strQBEIns = 'Lis';
$strQueryCache = 'Kyselyvlimuisti';
$strQueryFrame = 'Kyselyikkuna';
$strQueryOnDb = 'Suorita SQL-kysely tietokannassa <b>%s</b>:';
$strQueryResultsOperations = 'Kyselytulosten toimenpiteet';
$strQuerySQLHistory = 'SQL-historia';
$strQueryStatistics = '<b>Kyselytilastot</b>: Tlle palvelimelle on lhetetty viime kynnistyksest lhtien %s kysely.';
$strQueryTime = 'kysely kesti %01.4f sek.';
$strQueryType = 'Kyselyn tyyppi';
$strQueryWindowLock = 'l korvaa tt kysely ikkunan ulkopuolelta';

$strReadRequests = 'Hakupyynnt';
$strReceived = 'Vastaanotettu';
$strRecommended = 'suositeltava';
$strRecords = 'Rivit';
$strReferentialIntegrity = 'Tarkista viitteiden eheys:';
$strRefresh = 'Pivit';
$strRelationalSchema = 'Relaatioskeema';
$strRelationDeleted = 'Relaatio poistettu';
$strRelationNotWorking = 'Linkitettyihin tauluihin liittyvt lisominaisuudet on poistettu kytst. Katso %slistietoja%s.';
$strRelationsForTable = 'RELAATIOT TAULULLE';
$strRelations = 'Relaatiot';
$strRelationView = 'Relaationkym';
$strReloadingThePrivileges = 'Ladataan kyttoikeuksia uudelleen';
$strReload = 'Lataa uudelleen';
$strReloadPrivileges = 'Lataa kyttoikeudet uudelleen';
$strRemoveSelectedUsers = 'Poista valitut kyttjt';
$strRenameDatabaseOK = 'Tietokannan %s uusi nimi on nyt %s';
$strRenameTable = 'Nime taulu uudelleen';
$strRenameTableOK = 'Taulun %s nimi on nyt %s';
$strRepairTable = 'Korjaa taulu';
$strReplaceNULLBy = 'Korvaa NULL-merkki tll:';
$strReplaceTable = 'Korvaa taulun nykyiset rivit tiedostolla';
$strReplication = 'Replikaatio';
$strReset = 'Nollaa';
$strResourceLimits = 'Resurssirajoitukset';
$strReType = 'Kirjoita uudelleen';
$strRevokeAndDeleteDescr = 'Kyttjill on USAGE-kyttoikeus siihen asti, kun kyttoikeudet ladataan uudelleen.';
$strRevokeAndDelete = 'Pura kaikki kyttjn aktiiviset kyttoikeudet, ja poista ne sen jlkeen.';
$strRevokeMessage = 'Olet peruuttanut kyttjn %s kyttoikeudet';
$strRevoke = 'Mitti';
$strRomanian = 'Romanialainen';
$strRowLength = 'Rivin pituus';
$strRowsFrom = 'rivi alkaen rivist';
$strRowSize = ' Rivin koko ';
$strRows = 'Kpl rivej';
$strRowsModeFlippedHorizontal = 'vaakatasossa (kierretyt otsikot)';
$strRowsModeHorizontal = 'vaakasuorassa';
$strRowsModeOptions = '%s, otsikoita toistetaan %s:n rivin vlein';
$strRowsModeVertical = 'pystysuorassa';
$strRowsStatistic = 'Rivitilastot';
$strRunning = 'palvelimella %s';
$strRunQuery = 'Suorita';
$strRunSQLQueryOnServer = 'Suorita SQL-kysely(j) palvelimella %s';
$strRunSQLQuery = 'Suorita SQL-kyselyj tietokannassa %s';
$strRussian = 'Venlinen';

$strSaveOnServer = 'Tallenna palvelimelle hakemistoon %s';
$strSavePosition = 'Tallenna sijainti';
$strSave = 'Tallenna';
$strScaleFactorSmall = 'Kaavio ei mahdu yhdelle sivulle tll skaalauksella';
$strSearch = 'Etsi';
$strSearchFormTitle = 'Hae tietokannasta';
$strSearchInTables = 'Tauluista:';
$strSearchNeedle = 'Haettavat sanat tai arvot (%-merkki voi kytt jokerimerkkin):';
$strSearchOption1 = 'vhintn yksi sanoista';
$strSearchOption2 = 'kaikki sanat';
$strSearchOption3 = 'koko lause';
$strSearchOption4 = 'regexp-haku';
$strSearchResultsFor = 'Tulokset hakusanalla "<i>%s</i>" %s:';
$strSearchType = 'Hae:';
$strSecretRequired = 'Asetustiedosto vaatii nyt salalausetta (blowfish_secret).';
$strSelectADb = 'Valitse tietokanta';
$strSelectAll = 'Valitse kaikki';
$strSelectBinaryLog = 'Valitse nytettv binriloki';
$strSelectFields = 'Valitse sarakkeet (vhintn yksi):';
$strSelectForeignKey = 'Valitse vieras avain';
$strSelectNumRows = 'lauseessa';
$strSelectReferencedKey = 'Valitse viittaava avain';
$strSelectTables = 'Valitse taulut';
$strSend = 'Tallenna tiedostoon';
$strSent = 'Lhetetty';
$strServerChoice = 'Valitse palvelin';
$strServerNotResponding = 'Palvelin ei vastaa';
$strServer = 'Palvelin';
$strServers = 'Palvelimet';
$strServerStatus = 'Ajonaikaiset tiedot';
$strServerStatusDelayedInserts = 'Viivstetyt insert-lauseet';
$strServerStatusUptime = 'Tm MySQL-palvelin on ollut kynniss %s. Se kynnistettiin %s.';
$strServerTabVariables = 'Muuttujat';
$strServerTrafficNotes = '<b>Palvelinliikenne</b>: Nm taulukot nyttvt tmn MySQL-palvelimen verkkoliikennetilastot kynnistyksest lhtien.';
$strServerVars = 'Palvelimen muuttujat ja asetukset';
$strServerVersion = 'Palvelimen versio';
$strSessionStartupErrorGeneral = 'Istuntoa ei voida aloittaa virheitt. Tarkista PHP:n tai verkkopalvelimesi lokitiedostojen antamat virheilmoitukset ja valitse PHP-asennuksen asetukset oikein.';
$strSessionValue = 'Tmn istunnon arvo';
$strSetEnumVal = 'Jos sarakkeen tietotyyppi on "enum" tai "set", syt vaaditut arvot tss muodossa: \'a\',\'b\',\'c\'...<br />Jos tarvitset arvoissa kenoviivaa ("\") tai heittomerkki ("\'"), laita merkin eteen kenoviiva (esim. \'\\\\xyz\' tai \'a\\\'b\').';
$strShowAll = 'Nyt kaikki';
$strShowColor = 'Nyt vrit';
$strShowDatadictAs = 'Datasanakirjan formaatti';
$strShowFullQueries = 'Nyt kyselyt kokonaisuudessaan';
$strShowGrid = 'Nyt ruudukko';
$strShowHideLeftMenu = 'Nyt/ktke vasen valikko';
$strShowingBookmark = 'Nytetn kirjanmerkki';
$strShowingPhp = 'Nytetn PHP-koodina';
$strShowingRecords = 'Nkyvill rivit ';
$strShowingSQL = 'Nytetn SQL-kysely';
$strShow = 'Nyt';
$strShowOpenTables = 'Nyt avoimet taulut';
$strShowPHPInfo = 'Nyt PHP:n asetustiedot';
$strShowSlaveHosts = 'Nyt alipalvelimet';
$strShowSlaveStatus = 'Nyt alipalvelimen tila';
$strShowStatusBinlog_cache_disk_useDescr = 'Kertoo tilapist binrilokivlimuistia kyttneiden transaktioiden (tapahtumien) mrn, mutta jotka ovat ylittneet "binlog_cache_size"-muuttujan arvon ja kyttneet vliaikaistiedostoa transaktiokyselyjen tallentamiseen.';
$strShowStatusBinlog_cache_useDescr = 'Vliaikaista binrilokivlimuistia kyttneiden transaktioiden (tapahtumien) mr.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Kertoo, kuinka paljon palvelimen automaattisesti luomia tilapistauluja on levyll. Jos Created_tmp_disk_tables-parametrin arvo on liian suuri, nosta tmp_table_size:n arvoa, jotta vliaikaisia tauluja silytettisiin muistissa eik levyll.';
$strShowStatusCreated_tmp_filesDescr = 'Mysqld-palvelun luomien vliaikaistiedostojen mr.';
$strShowStatusCreated_tmp_tablesDescr = 'Kertoo, kuinka monta tilapistaulua palvelin on itsestn luonut muistiin kyselyj suorittaessaan.';
$strShowStatusDelayed_errorsDescr = 'Virheen aiheuttaneiden INSERT DELAYED -kyselyll kirjoitettujen rivien mr (virheen todennkisesti pllekkinen avain).';
$strShowStatusDelayed_insert_threadsDescr = 'Kytss olevien INSERT DELAYED -ksittelijsikeiden mr. Joka ikinen INSERT DELAYED -kysely kyttv taulu saa kyttns oman sikeens.';
$strShowStatusDelayed_writesDescr = 'INSERT DELAYED -rivien kirjoituksia.';
$strShowStatusFlush_commandsDescr  = 'FLUSH-kyselyj suoritettu.';
$strShowStatusHandler_commitDescr = 'Sisisten COMMIT-kyselyjen mr.';
$strShowStatusHandler_deleteDescr = 'Kertoo, kuinka monta kertaa taulusta on poistettu rivi.';
$strShowStatusHandler_discoverDescr = 'MySQL-palvelin voi kysy NDB Cluster -tallennustilamoottorilta, tunteeko se tietyn nimisen taulun. Tt toimintoa kutsutaan todentamiseksi (discovery). Handler_discover ilmaisee todennettujen taulujen mrn.';
$strShowStatusHandler_read_firstDescr = 'Kertoo, kuinka monta kertaa ensimmist kohtaa on luettu indeksist. Jos tm on suuri, se kertoo siit, ett palvelin suorittaa runsaasti kokonaisia indeksien lpikyntej; esimerkiksi SELECT col1 FROM foo, olettaen col1:sen olevan indeksoitu sarake.';
$strShowStatusHandler_read_keyDescr = 'Kertoo, kuinka monta kertaa rivej on luettu avaimen perusteella. Jos tm on suuri, se kertoo siit, ett kyselyjesi ja taulujesi indeksointi suoritetaan oikein.';
$strShowStatusHandler_read_nextDescr = 'Kertoo niiden pyyntjen mrn, jotka lukevat seuraavan rivin avainjrjestyksess. Tmn arvo kasvaa suorittaessasi kyselyj indeksisarakkeeseen aluerajoitetta kytten tai suorittaessasi indeksihaun.';
$strShowStatusHandler_read_prevDescr = 'Kertoo niiden pyyntjen mrn, jotka lukevat edellisen rivin avainjrjestyksess. Tt lukumenetelm kytetn lhinn ORDER BY ... DESC -kyselyll optimoimiseen.';
$strShowStatusHandler_read_rndDescr = 'Kertoo niiden pyyntjen mrn, jotka lukevat rivin kiinten sijainnin perusteella. Tm on suuri, jos suoritat paljon kyselyj, jotka edellyttvt tulostietojen lajittelua. Kytt ehk runsaasti sellaisia kyselyj, jotka edellyttvt MySQL-palvelinta kymn lpi kaikki taulut, tai virheellisesti avaimia kyttvi liitoksia.';
$strShowStatusHandler_read_rnd_nextDescr = 'Kertoo, kuinka usein pyynnill on luettu seuraava rivi datatiedostosta. Tm on suuri, jos kyt lpi paljon kokonaisia tauluja. Tm luku kertoo yleens siit, ett taulujasi ei ole indeksoitu oikein tai ett kyselyj ei ole kirjoitettu siten, ett ne hydyntisivt luomiasi indeksej.';
$strShowStatusHandler_rollbackDescr = 'Sisisten ROLLBACK-kyselyjen mr.';
$strShowStatusHandler_updateDescr = 'Taulun rivien pivityspyyntjen mr.';
$strShowStatusHandler_writeDescr = 'Kertoo tauluihin sijoitettujen (INSERT) rivien mrn.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Jotakin dataa (epsiisti tai siisti) sisltvien sivujen mr';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Tll hetkell epsiistin olevien sivujen mr.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Siistittviksi pyydettyjen, puskurivarannossa olevien sivujen mr.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Vapaiden sivujen mr.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'InnoDB-puskurivarannon lukittujen sivujen mr. Nm ovat sivuja, joita parhaillaan luetaan tai kirjoitetaan tai joita ei voida poistaa tai joiden vlimuistia ei voida tyhjent syyst tai toisesta.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Kertoo niiden sivujen mrn, jotka ovat kytss administratiivisen ylijmn, kuten rivinlukitusten tai mukautuvien salausindeksien, varaamisen takia. Tm arvo voidaan laskea ninkin: Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Puskurivarannon kokonaiskoko sivuina.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'InnoDB:n alulle panemien umpimhkisten ennakkolukutapausten mr. Tm tapahtuu silloin kun suoritetaan kysely, joka ky lpi suuria alueita taulusta umpimhkisess jrjestyksess.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'InnoDB:n alulle panemien perttisten ennakkolukutapausten mr. Tm tapahtuu silloin kun InnoDB ky lpi kokonaisen taulun jrjestyksess.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'InnoDB:n suorittamien loogisten lukupyyntjen mr.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Kertoo niiden loogisten lukukertojen mrn, joita InnoDB ei voinut toteuttaa puskurivarannosta joutuen lukemaan yhden sivun kerrallaan.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Yleens InnoDB-puskurivarannon kirjoituspyynnt suoritetaan taustalla. Jos kuitenkin on luettava tai luotava sivu, ja puhtaita sivuja ei ole saatavilla, joudutaan odottamaan sivujen tyhjentmist. Tm laskuri laskee tllaisten odotustapausten mrn. Jos puskurivarannon koko on asetettu sopivaksi, tmn arvon pitisi olla alhainen.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'InnoDB:n puskurivarantoon tehtyjen kirjoituspyyntjen mr.';
$strShowStatusInnodb_data_fsyncsDescr = 'fsync()-toimenpiteit thn menness.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Tll hetkell kynniss olevien fsync()-toimenpiteiden mr.';
$strShowStatusInnodb_data_pending_readsDescr = 'Tll hetkell kynniss olevien lukutoimenpiteiden mr.';
$strShowStatusInnodb_data_pending_writesDescr = 'Tll hetkell kynniss olevien kirjoitustoimenpiteiden mr.';
$strShowStatusInnodb_data_readDescr = 'Thn menness luetun tiedon mr tavuina.';
$strShowStatusInnodb_data_readsDescr = 'Kertoo, kuinka monta kertaa tietoja on luettu yhteens.';
$strShowStatusInnodb_data_writesDescr = 'Kertoo, kuinka monta kertaa tietoja on kirjoitettu yhteens.';
$strShowStatusInnodb_data_writtenDescr = 'Kertoo, kuinka paljon on thn menness tietoja kirjoitettu (tavuina).';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Suoritettujen pllekkisten kirjoitustapausten mr ja tt varten kirjoitettujen sivujen mr.';
$strShowStatusInnodb_dblwr_writesDescr = 'Suoritettujen pllekkisten kirjoitustapausten mr ja tt varten kirjoitettujen sivujen mr.';
$strShowStatusInnodb_log_waitsDescr = 'Liian pienest lokipuskurista johtuneiden odotusten mr, jolloin puskurin tyhjentmist jouduttiin odottamaan ennen jatkamista.';
$strShowStatusInnodb_log_write_requestsDescr = 'Lokikirjoituspyyntjen mr.';
$strShowStatusInnodb_log_writesDescr = 'Kertoo, kuinka monta kertaa lokitiedostoon on fyysisesti kirjoitettu.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Lokitiedostojen fsync()-kirjoitusten mr.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Lokitiedoston avointen fsync-synkronointien mr.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Avoimet lokitiedostokirjoitukset.';
$strShowStatusInnodb_os_log_writtenDescr = 'Lokitiedostoon kirjoitettujen tavujen mr.';
$strShowStatusInnodb_pages_createdDescr = 'Luotujen sivujen mr.';
$strShowStatusInnodb_page_sizeDescr = 'InnoDB-sivun esiohjelmoitu koko (oletusarvoisesti se on 16 kt). Useita arvoja lasketaan sivuina; sivukoon avulla voidaan helposti laskea niiden koko tavuina.';
$strShowStatusInnodb_pages_readDescr = 'Luettujen rivien mr.';
$strShowStatusInnodb_pages_writtenDescr = 'Kirjoitettujen sivujen mr.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Tll hetkell odotettavien rivilukitusten mr.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Rivilukituksen valmistumiseen kuluva aika keskimrin, millisekunteina.';
$strShowStatusInnodb_row_lock_timeDescr = 'Rivilukitusten valmistumiseen kuluva aika kaikkinansa, millisekunteina.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Rivilukituksen valmistumiseen kulunut aika enimmilln, millisekunteina.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Kertoo, kuinka monta kertaa rivilukitusta on jouduttu odottamaan.';
$strShowStatusInnodb_rows_deletedDescr = 'InnoDB-tauluista poistettujen rivien mr.';
$strShowStatusInnodb_rows_insertedDescr = 'InnoDB-tauluihin listtyjen rivien mr.';
$strShowStatusInnodb_rows_readDescr = 'InnoDB-taulusta luettujen rivien mr.';
$strShowStatusInnodb_rows_updatedDescr = 'InnoDB-taulun pivitettyjen rivien mr.';
$strShowStatusKey_blocks_not_flushedDescr = 'Niiden avainvlimuistissa sijaitsevien avainlohkojen mr, joihin on tehty muutoksia, mutta joita ei viel ole tallennettu levylle. Tm toiminto tunnetaan yleisesti nimell Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Avainvlimuistissa sijaitsevien kyttmttmien lohkojen mr. Tmn arvon avulla voit mritt, kuinka paljon avainvlimuistia halutaan olevan kytss.';
$strShowStatusKey_blocks_usedDescr = 'Samaan aikaan avainvlimuistissa olleiden lohkojen mr korkeintaan.';
$strShowStatusKey_read_requestsDescr = 'Kertoo, kuinka monta pyynt on suoritettu avainlohkon hakemiseksi vlimuistista.';
$strShowStatusKey_readsDescr = 'Kertoo, kuinka monta kertaa levylt on fyysisesti luettu avainlohkoja. Jos Key_reads-arvo on suuri, key_buffer_size-muuttujaan on ehk asetettu liian alhainen arvo. Vlimuistin kytttahti voidaan laskea lausekkeella Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Kertoo, kuinka monta kertaa vlimuistiin on kirjoitettu avainlohko.';
$strShowStatusKey_writesDescr = 'Kertoo, kuinka monta kertaa levylle on fyysisesti kirjoitettu avainlohko.';
$strShowStatusLast_query_costDescr = 'Viimeksi kootun (compiled) kyselyn kokonaiskulut kyselynoptimoija laskemana. Hydyllinen suunniteltaessa erilaisia kyselyvaihtoehtoja samaa kysely varten. Oletusarvo 0 tarkoittaa, ett yhtn kysely ei ole viel koottu.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Niiden rivien mr, joita odotetaan kirjoitettavan INSERT DELAYED -jonoissa.';
$strShowStatusOpened_tablesDescr = 'Avattujen taulujen mr. Jos mr on suuri, tauluvlimuistin arvo saattaa olla liian alhainen.';
$strShowStatusOpen_filesDescr = 'Avoinna olevien tiedostojen mr.';
$strShowStatusOpen_streamsDescr = 'Avoinna olevien voiden mr (kytetn enimmkseen kirjausta varten).';
$strShowStatusOpen_tablesDescr = 'Avoinna olevien taulujen mr.';
$strShowStatusQcache_free_blocksDescr = 'Vapaitten muistilohkojen mr kyselyvlimuistissa.';
$strShowStatusQcache_free_memoryDescr = 'Kyselyvlimuistin vapaan muistin mr.';
$strShowStatusQcache_hitsDescr = 'Vlimuistiosumien mr.';
$strShowStatusQcache_insertsDescr = 'Vlimuistiin sijoitettujen kyselyjen mr.';
$strShowStatusQcache_lowmem_prunesDescr = 'Niiden kyselyjen mr, jotka on poistettu vlimuistista muistin vapauttamiseksi, uusien kyselyjen tallentamiseksi vlimuistiin. Tmn tiedon avulla voit asettaa kyselyvlimuistin koon sopivaksi. Kyselyvlimuisti kytt LRU- eli "viimeksi vhiten kytetyt" -toimintamallia pttkseen, mitk kyselyt poistetaan vlimuistista.';
$strShowStatusQcache_not_cachedDescr = 'Niiden kyselyjen mr, joita ei ole tallennettu vlimuistiin (ei ole voitu tallentaa vlimuistiin tai ei muuten vain ole tallennettu sinne query_cache_type-asetuksen takia).';
$strShowStatusQcache_queries_in_cacheDescr = 'Rekisterityjen kyselyjen mr vlimuistissa.';
$strShowStatusQcache_total_blocksDescr = 'Lohkojen kokonaismr kyselyvlimuistissa.';
$strShowStatusReset = 'Nollaa';
$strShowStatusRpl_statusDescr = 'Replikaation vikasietotila (ei viel toteutettu).';
$strShowStatusSelect_full_joinDescr = 'Kertoo, kuinka moni liitos ei kyt indeksej. Jos tm arvo ei ole 0, sinun tulisi tarkistaa taulujesi indeksit tarkkaan.';
$strShowStatusSelect_full_range_joinDescr = 'Niiden liitosten mr, jotka kyttivt viitetaulussa (reference table) aluehakua.';
$strShowStatusSelect_range_checkDescr = 'Niiden avaimittomien liitosten mr, jotka varmistavat avaimien kytn joka rivin jlkeen. (Jos tm ei ole 0, sinun tulisi tarkistaa taulujesi indeksit huolella.)';
$strShowStatusSelect_rangeDescr = 'Kertoo niiden liitosten mrn, jotka kyttvt rajausta ensimmisess taulussa. (Yleens ei ole vakavaa, vaikka tm arvo olisi suuri.)';
$strShowStatusSelect_scanDescr = 'Kertoo niiden liitosten mrn, jotka suorittivat ensimmisest taulusta tydellisen tarkistuksen.';
$strShowStatusSlave_open_temp_tablesDescr = 'SQL-alisikeen avointen vliaikaistaulujen mr tll hetkell.';
$strShowStatusSlave_retried_transactionsDescr = 'Kertoo, kuinka monesti replikaation SQL-alisie on kaikkiaan uudelleen yrittnyt transkatioita kynnistyksest lhtien.';
$strShowStatusSlave_runningDescr = 'Tm on pll (ON), mikli kyseinen palvelin on ppalvelimeen kytketty alipalvelin.';
$strShowStatusSlow_launch_threadsDescr = 'Niiden sikeiden mr, joiden luomiseen on kulunut aikaa enemmn kuin slow_launch_time sekuntia.';
$strShowStatusSlow_queriesDescr = 'Niiden kyselyjen mr, joiden suorittamiseen on kulunut aikaa enemmn kuin long_query_time sekuntia.';
$strShowStatusSort_merge_passesDescr = 'Lajittelualgoritmiin tarvittavien yhdentymisten (eng. merge) mr. Jos tm arvo on suuri, voit suurentaa sort_buffer-muuttujan arvoa.';
$strShowStatusSort_rangeDescr = 'Alueiden (ranges) kanssa suoritettujen lajittelujen mr.';
$strShowStatusSort_rowsDescr = 'Lajiteltujen rivien mr.';
$strShowStatusSort_scanDescr = 'Niiden lajittelutoimenpiteiden mr, jotka on suoritettu kymll taulu lpi.';
$strShowStatusTable_locks_immediateDescr = 'Kertoo, kuinka monesti taulu on saatu lukittua heti.';
$strShowStatusTable_locks_waitedDescr = 'Kertoo, kuinka monesti taulua ei ole saatu heti lukittua ja on jouduttu odottamaan. Jos tm on suuri, ja suorituskyvyn kanssa on ongelmia, on hyv ensin optimoida kyselyj ja sitten joko jakaa taulusi useampaan osaan tai kytt hydyksi replikaatiota.';
$strShowStatusThreads_cachedDescr = 'Sievlimuistissa sijaitsevien sikeiden mr. Vlimuistin kytttahti voidaan laskea nin kaavalla Threads_created/yhteyksien lkm. Jos tm arvo on punainen, thread_cache_size-muuttujan arvoa tulisi nostaa.';
$strShowStatusThreads_connectedDescr = 'Tll hetkell avoinna olevien yhteyksien mr.';
$strShowStatusThreads_createdDescr = 'Yhteyksien ksittely varten luotujen sikeiden mr. Jos Threads_created on suuri, kannattaa kasvattaa thread_cache_size-muuttujan arvoa. (Mikli sikeet on toteutettu hyvin, tll ei ole kovin suurta vaikutusta suorituskykyyn.)';
$strShowStatusThreads_runningDescr = 'Hereill olevien sikeiden mr.';
$strShowTableDimension = 'Nyt taulujen ulottuvuus';
$strShowTables = 'Nyt taulut';
$strShowThisQuery = ' Nyt kyselylause uudelleen ';
$strSimplifiedChinese = 'Yksinkertaistettu kiina';
$strSingly = '(yksitellen)';
$strSize = 'Koko';
$strSkipQueries = 'Tiedoston alusta ohitettavien tietueiden (kyselyjen) mr';
$strSlovak = 'Slovakialainen';
$strSlovenian = 'Slovenialainen';
$strSmallBigAll = 'Kaikki pienen/suurena';
$strSnapToGrid = 'Sovita ruudukkoon';
$strSocketProblem = "(tai paikallisen MySQL-palvelimen sockettia ei ole konfiguroitu oikein)";
$strSortByKey = 'Lajittele avaimen mukaan';
$strSorting = 'Lajittelu';
$strSort = 'Jrjestys';
$strSpaceUsage = 'Levytilan kytt';
$strSpanish = 'Espanjalainen';
$strSplitWordsWithSpace = 'Sanat erotellaan vlilynnill.';
$strSQLCompatibility = 'SQL-yhteensopiva tila';
$strSQLExportType = 'Vientityyppi';
$strSQLParserBugMessage = 'Olet mahdollisesti lytnyt ohjelmointivirheen SQL-parserista. Tarkista SQL-lauseesi, erityisesti lainausmerkit merkkijonojen alusta ja lopusta. Toinen mahdollinen virheen aiheuttaja on se, ett olet siirtmss tiedostoa, jossa on binritietoa lainausmerkkien ulkopuolella. Jos mahdollista, kokeile SQL-lausettasi suoraan komentorivilt. MySQL-palvelimen antama virheilmoitus nkyy alla, mikli se sellaisen antoi. Jos lause toimi komentorivilt, mutta ei phpMyAdminista, etsi se rivi jolla virheilmoitus ilmeni ja lhet meille virheraportti, johon liitt alla olevan koodin:';
$strSQLParserUserError = 'SQL-lauseessasi nytt olevan jokin virhe. MySQL-palvelimen antama virheilmoitus nkyy alla, mikli palvelin sellaisen antoi.';
$strSQLQuery = 'SQL-kysely';
$strSQLResult = 'SQL-kyselyn tulos';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Tunniste ei kelpaa';
$strSQPBugUnclosedQuote = 'Toinen lainausmerkki puuttuu merkkijonon lopusta';
$strSQPBugUnknownPunctuation = 'Tuntematon vlimerkki';
$strStandInStructureForView = 'Nkymn sijaisrakenne';
$strStatCheckTime = 'Viimeksi tarkistettu';
$strStatCreateTime = 'Luotu';
$strStatement = 'Tieto';
$strStatisticsOverrun = 'Ruuhkaisten palvelinten tavulaskurit saattavat ylivuotaa, joten MySQL-palvelimen ilmoittamat tilastotiedot saattavat olla virheellisi.';
$strStatUpdateTime = 'Viimeksi pivitetty';
$strStatus = 'Tila';
$strStorageEngines = "Tallennustilamoottorit";
$strStorageEngine = "Tallennustilamoottori";
$strStrucCSV = 'CSV-muotoista tietoa';
$strStrucData = 'Rakenne ja tiedot';
$strStrucExcelCSV = 'MS Excelin CSV-muoto';
$strStrucNativeExcel = 'Natiivi MS Excel -tieto';
$strStrucOnly = 'Vain rakenne';
$strStructPropose = 'Esit taulun rakenne';
$strStructureForView = 'Nkymn rakenne';
$strStructure = 'Rakenne';
$strSubmit = 'Lhet';
$strSuccess = 'SQL-kysely suoritettu onnistuneesti';
$strSum = 'Summa';
$strSwedish = 'Ruotsalainen';
$strSwitchToDatabase = 'Siirry kopioituun tietokantaan';
$strSwitchToTable = 'Siirry kopioituun tauluun';

$strTableAlreadyExists = 'Taulu %s on jo olemassa!';
$strTableComments = 'Taulun kommentit';
$strTableEmpty = 'Taulun nimi puuttuu!';
$strTableHasBeenDropped = 'Taulu %s on pudotettu';
$strTableHasBeenEmptied = 'Taulu %s on tyhjennetty';
$strTableHasBeenFlushed = 'Taulun %s vlimuisti on tyhjennetty';
$strTableIsEmpty = 'Taulu on tyhj!';
$strTableMaintenance = 'Taulun huolto';
$strTableName = 'Taulun nimi';
$strTableOfContents = 'Sisllysluettelo';
$strTableOptions = 'Taulun valinnat';
$strTables = '%s taulu(a)';
$strTableStructure = 'Rakenne taululle';
$strTable = 'Taulu';
$strTakeIt = 'kyt tt';
$strTblPrivileges = 'Taulukohtaiset kyttoikeudet';
$strTempData = 'Vliaikaista tietoa';
$strTextAreaLength = ' Pituudestaan johtuen<br /> tt saraketta ei ehk voi muokata ';
$strThai = 'Thai';
$strThemeDefaultNotFound = 'Oletusteemaa %s ei lydy!';
$strThemeNoPreviewAvailable = 'Esikatselu ei ole saatavilla.';
$strThemeNotFound = 'Teemaa %s ei lydy!';
$strThemeNoValidImgPath = 'Kelvollista polkua teemalle %s ei lytynyt.';
$strThemePathNotFound = 'Teeman %s polkua ei lydy!';
$strTheme = 'Teema/tyyli';
$strThisHost = 'Tm isnt';
$strThreads = 'Sikeet';
$strThreadSuccessfullyKilled = 'Sikeen %s lopetus onnistui.';
$strTime = 'Aika';
$strTimeoutInfo = 'Edellinen tuonti keskeytyi aikakatkaisuun; lhetettysi tiedoston uudestaan jatkamme kohdasta %d.';
$strTimeoutNothingParsed = 'Viimeisest suorituskerrasta huolimatta mitn tietoa ei ole jsennelty; tm tarkoittaa yleens sit, ett phpMyAdmin ei voi suorittaa tt tuontia loppuun asti, ellei php:n suoritusaikarajaa kasvateta.';
$strTimeoutPassed = 'Skriptin suoritus aikakatkaistiin; jos haluat suorittaa tuonnin loppuun saakka, lhet sama tiedosto uudestaan, ja tuomista voidaan jaktaa.';
$strToFromPage = 'Sivulta/sivulle';
$strToggleScratchboard = 'Nyt/ktke luonnospyt (scratchboard)';
$strToggleSmallBig = 'Vaihda pieneksi/suureksi';
$strToSelectRelation = 'Valitaksesi relaation, paina :';
$strTotalUC = 'Yhteens';
$strTotal = 'yhteens';
$strTraditionalChinese = 'Perinteinen kiina';
$strTraditionalSpanish = 'Perinteinen espanja';
$strTraffic = 'Liikenne';
$strTransactionCoordinator = 'Transaktion (tapahtuman) koordinaattori';
$strTransformation_application_octetstream__download = 'Nyt linkki kentn binritiedon lataamiseen. Ensimminen valinta on binritiedoston tiedostonimi. Toinen valinta on mahdollisen taulun rivin kenttnimi, jolla tiedostonimi sijaitsee. Jos kytt toista (2) valintaa, sinun on asetettava ensimminen valinta tyhjksi.';
$strTransformation_application_octetstream__hex = 'Nytt tiedon heksalukuina. Valinnainen, ensimminen parametri mrittelee, kuinka usein vlilynti listn (oletusarvo on 2).';
$strTransformation_image_jpeg__inline = 'Nytt klikattavan pikkukuvan; valinnat: leveyden,korkeuden pikselein (silytt alkuperisen suhteen)';
$strTransformation_image_jpeg__link = 'Nytt linkin thn kuvaan (eli suora blob-imurointi).';
$strTransformation_image_png__inline = 'Katso image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Nytt kentn muotoiltuna pivmrn TIME-, TIMESTAMP-, DATETIME- tai numeerisen UNIX-aikaleiman pohjalta. Ensimminen valinta on aikaleimaan (oletuksena 0) listtv siirros (tunteina). Toisella valinnalla on mahdollista mritt eri muotoinen pivysmerkkijono. Kolmas valinta mr, kytetnk pivyksess paikallis- vai UTC-aikaa (kyt "local"- tai "utc"-merkkijonoja). Pivyksen muodossa kytetn asetuksen mukaisesti erilaista arvoa; katso ohjeet "local"-asetuksen kytst PHP:n dokumentaation strftime()-funktiosta, "utc"-asetus taas kytt gmdate()-funktiota.';
$strTransformation_text_plain__external = 'VAIN LINUXILLE: Kynnist ulkoisen ohjelman ja sytt kentttiedot oletusarvoisen sytteen kautta. Palauttaa ohjelman oletusarvoisen tulosteen. Oletusarvona on Tidy, HTML-koodin tulostamiseksi siististi. Tietoturvasyist joudut muokkaamaan ksin tiedostoa libraries/transformations/text_plain__external.inc.php ja lismn tykalut, joiden ajon haluat sallia. Ensimminen valinta on silloin haluamasi ohjelman numero ja toinen valinta mritt ohjelmalle annettavat parametrit. Kolmannen parametrin ollessa yksi (1) tuloste muunnetaan kytten htmlspecialchars()-funktiota (Oletus on 1). Neljnnen parametrin ollessa yksi (1) sisltkennoon listn NOWRAP, jotta koko tuloste nkyy ilman ennakkomuotoiluja (Oletus 1)';
$strTransformation_text_plain__formatted = 'Silytt kentn alkuperiset muotoilut. Kenoviivoja ei kytet erikoismerkkien edell.';
$strTransformation_text_plain__imagelink = 'Nytt kuvan ja linkin, kentt sislt tiedostonimen; ensimminen valinta on etuliite, eli esimerkiksi "http://domain.com/", toinen valinta on leveys pikselein, kolmas on korkeus.';
$strTransformation_text_plain__link = 'Nytt linkin, kentt sislt tiedostonimen; ensimminen valinta on etuliite, eli esimerkiksi "http://domain.com/", toinen valinta on linkin otsikko.';
$strTransformation_text_plain__sql = 'Muotoilee SQL-kyselyn syntaksivrityksell.';
$strTransformation_text_plain__substr = 'Nytt vain osan merkkijonoa. Ensimminen valinta on tarkoitettu mrittelemn siirrosta, jonka kohdalta tekstin nyttminen aloitetaan (Oletus: 0). Toinen valinta kertoo, kuinka monta merkki tekstist nytetn. Tmn ollessa tyhj merkkijonosta nytetn kaikki loput tekstit. Kolmas valinta mrittelee, mit merkkej merkkijonon pern listn sit nytettess (Oletus: "...") .';
$strTruncateQueries = 'Nyt typistetyt kyselyt';
$strTurkish = 'Turkkilainen';
$strType = 'Tyyppi';

$strUkrainian = 'Ukrainalainen';
$strUncheckAll = 'Poista valinta kaikista';
$strUnicode = 'Unicode';
$strUnique = 'Uniikki';
$strUnknown = 'tuntematon';
$strUnselectAll = 'Poista valinta kaikista';
$strUnsupportedCompressionDetected = 'Yritit ladata tiedostoa, joka kytt tuntematonta pakkausmuotoa (%s). Tukea kyseiselle muodolle ei joko ole toteutettu, tai se on asetuksin poistettu kytst.';
$strUpdatePrivMessage = 'Kyttjn %s kyttoikeudet on pivitetty.';
$strUpdateProfileMessage = 'Profiili on pivitetty.';
$strUpdateQuery = 'Pivit kysely';
$strUpdComTab = 'Tarkista dokumentaatiosta, kuinka voit pivitt Column_comments-taulusi';
$strUpgrade = 'Sinun pitisi pivitt versioon %s %s tai sit myhempn versioon.';
$strUploadErrorCantWrite = 'Tiedoston kirjoitus levylle eponnistui.';
$strUploadErrorExtension = 'Laajennus keskeytti tiedoston lhetyksen.';
$strUploadErrorFormSize = 'Lhetetyn tiedoston koko ylitt HTML-lomakkeessa mritetyn MAX_FILE_SIZE-asetuksen arvon.';
$strUploadErrorIniSize = 'Lhetyn tidoston koko ylitt php.ini-tiedoston upload_max_filesize-asetuksen arvon.';
$strUploadErrorNoTempDir = 'Tilapiskansio puuttuu.';
$strUploadErrorPartial = 'Tiedosto lhetettiin vain osittain.';
$strUploadErrorUnknown = 'Tuntematon virhe tiedostoa lhetettess.';
$strUploadLimit = 'Yritit todennkisesti lhett palvelimelle liian suurta tiedostoa. Katso listietoja %sdokumentaatiosta%s tmn rajoituksen muuttamiseksi.';
$strUploadsNotAllowed = 'Tiedostojen lhetyst ei ole sallittu tll palvelimella.';
$strUsage = 'Kytt';
$strUseBackquotes = 'Pane taulujen ja sarakkeiden nimet lainausmerkkeihin';
$strUsedPhpExtensions = 'Kytss olevat PHP-laajennukset';
$strUseHostTable = 'Kyt palvelintaulua';
$strUserAlreadyExists = 'Kyttj %s on jo olemassa!';
$strUserEmpty = 'Kyttjn nimi puuttuu!';
$strUser = 'Kyttj';
$strUserName = 'Kyttjnimi';
$strUserNotFound = 'Valittua kyttj ei lytynyt kyttoikeustaulusta.';
$strUserOverview = 'Kyttjien yleiskatsaus';
$strUsersDeleted = 'Valitsemiesi kyttjien poisto onnistui.';
$strUsersHavingAccessToDb = 'Kyttjt, joilla on oikeus kytt kohdetta &quot;%s&quot;';
$strUseTabKey = 'Kyt arvojen vlill siirtymiseen sarkainta. Ctrl- ja nuolinppimill voit siirty mihin tahansa kohtaan.';
$strUseTables = 'Kyt tauluja';
$strUseTextField = 'Kyt tekstikentt';
$strUseThisValue = 'Kyt tt arvoa';

$strValidateSQL = 'Tarkista SQL-kysely';
$strValidatorError = 'SQL-kelpuutinta ei voitu kynnist. Tarkista, ett olet asentanut tarpeelliset PHP-laajennukset. Listietoa lytyy %sdokumentaatiosta%s.';
$strValue = 'Arvo';
$strVar = 'Muuttuja';
$strVersionInformation = "Versiotiedot";
$strViewDumpDatabases = 'Nyt tietokannoista vedos (skeema)';
$strViewDumpDB = 'Tee vedos tietokannasta';
$strViewDump = 'Tee vedos taulusta';
$strViewHasBeenDropped = "Nkym %s on poistettu";
$strViewMaxExactCount = 'Tss nkymss on yli %s rivi. Katso listietoja %sdokumentaatiosta%s.';
$strView = "Nkym";
$strViewName = 'VIEW-arvon nimi';

$strWebServerUploadDirectoryError = 'Valitsemaasi hakemistoa ei voitu kytt tiedostojen siirtmiseen';
$strWebServerUploadDirectory = 'palvelimen hakemisto tiedostojen siirtoa varten';
$strWelcome = 'Tervetuloa, toivottaa %s';
$strWestEuropean = 'Lnsieurooppalainen';
$strWildcard = 'jokerimerkki';
$strWindowNotFound = 'Kohdeselainikkunaa ei voitu pivitt. Syyn voi olla se, ett olet sulkenut isntikkunan tai ett selaimesi tietoturva-asetukset estvt ikkunoiden vliset pivitystoiminnot.';
$strWithChecked = 'Valitut:';
$strWriteRequests = 'Kirjoituspyynnt';
$strWrongUser = 'Vr kyttjtunnus tai salasana. Psy kielletty.';

$strXML = 'XML';

$strYes = 'Kyll';

$strZeroRemovesTheLimit = 'Huom: Niden valintojen asettaminen nollaksi (0) poistaa rajoituksen.';
$strZip = '"zip-pakattu"';

$strFiles = 'Files';  //to translate
$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
$strRoutines = 'Routines';  //to translate
$strRoutineReturnType = 'Return type';  //to translate
$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
$strTriggers = 'Triggers';  //to translate
$strEvent = 'Event';  //to translate
$strProfiling = 'Profiling';  //to translate
$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
?>
